==> proxy-store-1.0.1.tgz: package/README.md <==

## How to use.

##### First install npm package

`npm i --save proxy-store`

##### import necessary files on top of your javascript file.

`import createStore, { observer } from "proxy-store";`

##### Now lets create new storage.

For that create an object that will be the state of your app, for example a todos app minimal state would look like this

```
let data = {
            name:"random",
            todos:[
              { name:"walk dog", date:"today", done:true },
              { name:"buy food", date:"tomorrow", done:false }
            ]
          };
```

##### Then create new store with this data

`let store = createStore(data);`

##### Add observer decorator to React Component

`@observer class MyComponent extends Component`

Now all the data that you created in you object can be reached from you app with props
like this

`<span>{this.props.name}</span>`

But to get data from array you must use `Array.from(this.props.todos)`,
because some why proxy makes the array into object, maybe this can be fixed soon.

For example you are trying to map and show the todos list you need to use it like this
```
 { Array.from(this.props.todos).map((item, index) => {
                    return <div onClick={this.toggleTodo.bind(this, item.name )} key={index} className={`todo ${item.done ? "done" : ""}` }>
                              <span>{item.name}</span>
                              <span>{item.date}</span>
                           </div>
                  })
                }
```
See example here

https://github.com/tonis2/react-proxy-store

==> proxy-store-1.0.2.tgz: package/README.md <==

## How to use.

##### First install npm package

`npm i --save proxy-store`

##### import necessary files on top of your javascript file.

`import createStore from "proxy-store";`

##### Now lets create new storage.

For that create an object that will be the state of your app, for example a todos app minimal state would look like this

```
let data = {
            name:"random",
            todos:[
              { name:"walk dog", date:"today", done:true },
              { name:"buy food", date:"tomorrow", done:false }
            ]
          };
```

##### Then create new store with this data

`let store = new createStore(data);`

##### Add observer decorator to React Component

`@store.observer class MyComponent extends Component`

Now all the data that you created in you object can be reached from you app with props
like this

`<span>{this.props.name}</span>`

But to get data from array you must use `Array.from(this.props.todos)`,
because some why proxy makes the array into object, maybe this can be fixed soon.

For example you are trying to map and show the todos list you need to use it like this
```
 { Array.from(this.props.todos).map((item, index) => {
                    return <div onClick={this.toggleTodo.bind(this, item.name )} key={index} className={`todo ${item.done ? "done" : ""}` }>
                              <span>{item.name}</span>
                              <span>{item.date}</span>
                           </div>
                  })
                }
```
##### Make changes to store
To update store simple use the store like regular javascript object, but use store.data

For example
`store.data.name = "Steve"`

Updates observed components `this.props.name` to "Steve"


See example here

https://github.com/tonis2/react-proxy-store

### I have no idea does this have good performance so use in simple projects.
